# Local folder named 'safe'

Do not change the name of this folder.
It is part of test where we ensure we can have local imports to folders that have the same name as dependencies.
In this case, we also have a dependency with key `@safe`.
